==> jc-1.4.0.tar.gz: java/util/jar/JarOutputStream.h <==
// public class java.util.jar.JarOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf88c9f9520d2e10 java_util_jar_JarOutputStream
// @dep_class f80e6f4ae1ff7e14 java_util_zip_DeflaterOutputStream
// @dep_class cae120da050b0377 java_util_zip_ZipOutputStream

// header file dependencies
// @dep_header java_util_zip_ZipOutputStream

#include "java/util/zip/ZipOutputStream.h"

#ifndef _JC_java_util_jar_JarOutputStream_H_
#define _JC_java_util_jar_JarOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_jar_Manifest$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_jar_JarOutputStream$sub_refs	_jc_java_util_jar_JarOutputStream$sub_refs;
typedef struct _jc_java_util_jar_JarOutputStream$sub_nonrefs	_jc_java_util_jar_JarOutputStream$sub_nonrefs;
typedef struct _jc_java_util_jar_JarOutputStream$refs	_jc_java_util_jar_JarOutputStream$refs;
typedef struct _jc_java_util_jar_JarOutputStream$nonrefs	_jc_java_util_jar_JarOutputStream$nonrefs;
typedef struct _jc_java_util_jar_JarOutputStream$object	_jc_java_util_jar_JarOutputStream$object;

typedef const struct _jc_java_util_jar_JarOutputStream$vmethods	_jc_java_util_jar_JarOutputStream$vmethods;
typedef const struct _jc_java_util_jar_JarOutputStream$vtable	_jc_java_util_jar_JarOutputStream$vtable;
typedef const struct _jc_java_util_jar_JarOutputStream$vtype	_jc_java_util_jar_JarOutputStream$vtype;

// Constructors
extern void _jc_java_util_jar_JarOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_java_util_jar_JarOutputStream$method$_init$de208013830d3286(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_util_jar_Manifest$object *);

// Virtual methods
extern void _jc_java_util_jar_JarOutputStream$method$putNextEntry$8f69a8523d1dfc98(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_util_zip_ZipEntry$object *);
extern void _jc_java_util_jar_JarOutputStream$method$writeManifest$db9610ca718278c6(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_util_jar_Manifest$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarOutputStream$method_info$putNextEntry$8f69a8523d1dfc98;
extern _jc_method _jc_java_util_jar_JarOutputStream$method_info$writeManifest$db9610ca718278c6;

// Virtual methods structure
struct _jc_java_util_jar_JarOutputStream$vmethods {
	void	(*putNextEntry$8f69a8523d1dfc98)(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_util_zip_ZipEntry$object *);
	void	(*writeManifest$db9610ca718278c6)(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_util_jar_Manifest$object *);
};

// Vtable
struct _jc_java_util_jar_JarOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_DeflaterOutputStream$vmethods	java_util_zip_DeflaterOutputStream;
	_jc_java_util_zip_ZipOutputStream$vmethods	java_util_zip_ZipOutputStream;
	_jc_java_util_jar_JarOutputStream$vmethods	java_util_jar_JarOutputStream;
};

// Vtype
struct _jc_java_util_jar_JarOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarOutputStream$refs {
    _jc_java_util_jar_JarOutputStream$sub_refs	java_util_jar_JarOutputStream;
    _jc_java_util_zip_ZipOutputStream$sub_refs	java_util_zip_ZipOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_refs	java_util_zip_DeflaterOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	java_util_zip_DeflaterOutputStream;
    _jc_java_util_zip_ZipOutputStream$sub_nonrefs	java_util_zip_ZipOutputStream;
    _jc_java_util_jar_JarOutputStream$sub_nonrefs	java_util_jar_JarOutputStream;
};

// Object instance structure
struct _jc_java_util_jar_JarOutputStream$object {
	_jc_java_util_jar_JarOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarOutputStream$vtype	*vtype;
	_jc_java_util_jar_JarOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarOutputStream$vtype _jc_java_util_jar_JarOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarOutputStream$class_object;

#endif	/* _JC_java_util_jar_JarOutputStream_H_ */

==> jc-1.4.6.tar.gz: java/util/jar/JarOutputStream.h <==
// public class java.util.jar.JarOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cf88c9f9520d2e10 java_util_jar_JarOutputStream
// @dep_class f80e6f4ae1ff7e14 java_util_zip_DeflaterOutputStream
// @dep_class cae120da050b0377 java_util_zip_ZipOutputStream

// header file dependencies
// @dep_header java_util_zip_ZipOutputStream

#include "java/util/zip/ZipOutputStream.h"

#ifndef _JC_java_util_jar_JarOutputStream_H_
#define _JC_java_util_jar_JarOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_jar_Manifest$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_jar_JarOutputStream$sub_refs	_jc_java_util_jar_JarOutputStream$sub_refs;
typedef struct _jc_java_util_jar_JarOutputStream$sub_nonrefs	_jc_java_util_jar_JarOutputStream$sub_nonrefs;
typedef struct _jc_java_util_jar_JarOutputStream$refs	_jc_java_util_jar_JarOutputStream$refs;
typedef struct _jc_java_util_jar_JarOutputStream$nonrefs	_jc_java_util_jar_JarOutputStream$nonrefs;
typedef struct _jc_java_util_jar_JarOutputStream$object	_jc_java_util_jar_JarOutputStream$object;

typedef const struct _jc_java_util_jar_JarOutputStream$vmethods	_jc_java_util_jar_JarOutputStream$vmethods;
typedef const struct _jc_java_util_jar_JarOutputStream$vtable	_jc_java_util_jar_JarOutputStream$vtable;
typedef const struct _jc_java_util_jar_JarOutputStream$vtype	_jc_java_util_jar_JarOutputStream$vtype;

// Constructors
extern void _jc_java_util_jar_JarOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_jar_JarOutputStream$method$_init$de208013830d3286(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_util_jar_Manifest$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_jar_JarOutputStream$method$putNextEntry$8f69a8523d1dfc98(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_util_zip_ZipEntry$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_jar_JarOutputStream$method$writeManifest$db9610ca718278c6(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_util_jar_Manifest$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarOutputStream$method_info$putNextEntry$8f69a8523d1dfc98;
extern _jc_method _jc_java_util_jar_JarOutputStream$method_info$writeManifest$db9610ca718278c6;

// Virtual methods structure
struct _jc_java_util_jar_JarOutputStream$vmethods {
	void	(*putNextEntry$8f69a8523d1dfc98)(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_util_zip_ZipEntry$object *) _JC_JCNI_ATTR;
	void	(*writeManifest$db9610ca718278c6)(_jc_env *, struct _jc_java_util_jar_JarOutputStream$object *, struct _jc_java_util_jar_Manifest$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_jar_JarOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_util_zip_DeflaterOutputStream$vmethods	java_util_zip_DeflaterOutputStream;
	_jc_java_util_zip_ZipOutputStream$vmethods	java_util_zip_ZipOutputStream;
	_jc_java_util_jar_JarOutputStream$vmethods	java_util_jar_JarOutputStream;
};

// Vtype
struct _jc_java_util_jar_JarOutputStream$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarOutputStream$refs {
    _jc_java_util_jar_JarOutputStream$sub_refs	java_util_jar_JarOutputStream;
    _jc_java_util_zip_ZipOutputStream$sub_refs	java_util_zip_ZipOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_refs	java_util_zip_DeflaterOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_util_zip_DeflaterOutputStream$sub_nonrefs	java_util_zip_DeflaterOutputStream;
    _jc_java_util_zip_ZipOutputStream$sub_nonrefs	java_util_zip_ZipOutputStream;
    _jc_java_util_jar_JarOutputStream$sub_nonrefs	java_util_jar_JarOutputStream;
};

// Object instance structure
struct _jc_java_util_jar_JarOutputStream$object {
	_jc_java_util_jar_JarOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarOutputStream$vtype	*vtype;
	_jc_java_util_jar_JarOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarOutputStream$vtype _jc_java_util_jar_JarOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarOutputStream$class_object;

#endif	/* _JC_java_util_jar_JarOutputStream_H_ */
